Get-ADObject - Buscar objetos AD en Active Directory
El cmdlet Get-AdObject de PowerShell obtiene un objeto de Active Directory o realiza una búsqueda para obtener varios objetos según los criterios de búsqueda. Puede obtener todos los objetos en Active Directory utilizando el parámetro Filtro *.
El cmdlet Get-ADObject se conecta al controlador de dominio AD o al servidor Lightweight Directory Service y devuelve objetos del directorio activo. Get-ADObject utiliza el parámetro Identity para obtener objetos específicos de Active Directory. Puede utilizar un nombre distintivo o GUID para identificar el objeto.
De forma predeterminada, el cmdlet Get-ADObject devuelve solo 1000 objetos AD. Sin embargo, puede configurar el parámetro ResultSetSize para obtener una cantidad máxima de objetos.
Sintaxis de Get-ADObject
El cmdlet Get-AdObject obtiene uno o más objetos del directorio activo.
Sintaxis:
Get-ADObject
[-AuthType <ADAuthType>]
[-Credential <PSCredential>]
-Filter <String>
[-IncludeDeletedObjects]
[-Properties <String[]>]
[-ResultPageSize <Int32>]
[-ResultSetSize <Int32>]
[-SearchBase <String>]
[-SearchScope <ADSearchScope>]
[-Server <String>]
[<CommonParameters>]
Get-ADObject
[-AuthType <ADAuthType>]
[-Credential <PSCredential>]
[-IncludeDeletedObjects]
-LDAPFilter <String>
[-Properties <String[]>]
[-ResultPageSize <Int32>]
[-ResultSetSize <Int32>]
[-SearchBase <String>]
[-SearchScope <ADSearchScope>]
[-Server <String>]
[<CommonParameters>]
Parámetros:
-AuthType: Especifica el método de autenticación a utilizar. Los valores aceptables para este parámetro son Básico o Negociar. El método de autenticación predeterminado es Negociar.
-Credencial: Especifica las credenciales de la cuenta de usuario para realizar la tarea. De forma predeterminada, utiliza las credenciales del usuario que ha iniciado sesión actualmente. Puede utilizar el cmdlet Get-Credential para obtener las credenciales de usuario.
-Filtro: Especifica una cadena de consulta para recuperar Objetos de Active Directory. La cadena de consulta utiliza la sintaxis del lenguaje de expresión de PowerShell. Usando el parámetro Filter o LDAPFilter usado para buscar y obtener más de un objeto AD.
-Identidad: Especifica un objeto de Active Directory usando el nombre distinguido, GUID
-Properties: Especifica las propiedades del objeto AD que se recuperará del servidor. Para especificar propiedades para este parámetro, utilice una lista de nombres separados por comas. Utilice * (asterisco) para mostrar todos los atributos del objeto.
Entendamos cómo obtener objetos del directorio activo usando ejemplos de Get-ADObject.
Filtro Get-AdObject: obtenga todos los objetos AD
Puede obtener adobjects del directorio activo utilizando el parámetro Filtro. El filtro * obtiene todos los objetos publicitarios como se indica a continuación
Get-ADObject -Filter *El ejemplo anterior de Get-ADObject obtiene todos los objetos del directorio activo como el usuario, la computadora, el grupo, el contenedor, la unidad organizativa, etc.
Obtener-ADObject computadora de Active Directory
Puede obtener una computadora adobject del directorio activo usando el parámetro de filtro como se indica a continuación
Get-ADObject -Filter {(objectClass -eq "user") -and (objectCategory -eq "computer")}
En el script de PowerShell anterior, el cmdlet Get-AdObject obtiene computadoras del directorio activo.
Get-AdObject utiliza un parámetro Filter para especificar una cadena de consulta donde la clase de objeto es igual al usuario y la categoría del objeto es igual a la computadora.
El resultado del comando de computadora get-adobject anterior obtiene un nombre distintivo, un GUID de objeto y un nombre de computadora de objeto AD.
Get-ADObject -Filter {(objectClass -eq "user") -and (objectCategory -eq "computer")}
DistinguishedName Name ObjectClass ObjectGUID
----------------- ---- ----------- ----------
CN=ENG-PRO,OU=Domain Controllers,DC=SHELLPRO,DC=LOCAL ENG-PRO computer dbf9fc91-4f31-401e-b924-89cd0c6b26c0
CN=OPER-01,CN=Computers,DC=SHELLPRO,DC=LOCAL OPER-01 computer 69432246-a05e-4be1-bb38-1f047ds65b06Sólo usuarios de Get-ADObject
Puede obtener usuarios de adobject solo desde el directorio activo utilizando el parámetro de filtro como se indica a continuación
Get-ADObject -Filter {(objectClass -eq "user") -and (objectCategory -eq "user")}En el script de ejemplo Get-AdObject anterior, el cmdlet Get-AdObject obtiene usuarios del directorio activo.
Get-AdObject utiliza un parámetro de filtro para especificar una cadena de consulta donde la clase de objeto es igual a usuario y la categoría de objeto es igual a usuario.
El resultado del comando anterior get-adobject solo para usuarios obtiene un nombre distintivo, un nombre de usuario de adobject, una clase de objeto y un GUID de objeto como se muestra a continuación
Get-ADObject -Filter {(objectClass -eq "user") -and (objectCategory -eq "user")}
DistinguishedName Name ObjectClass ObjectGUID
----------------- ---- ----------- ----------
CN=Guest,CN=Users,DC=SHELLPRO,DC=LOCAL Guest user 1c4cede2-0375-49e6-a562-a5288713a3ec
CN=krbtgt,CN=Users,DC=SHELLPRO,DC=LOCAL krbtgt user f33e6e7e-4807-40aa-b2c1-846eea98135eConsejo interesante: ¡Cómo utilizar el cmdlet de cuenta de búsqueda en PowerShell!
Get-ADObject SearchBase: obtenga objetos AD de OU
Si desea obtener adobjects de la unidad organizativa específica en el directorio activo, use el parámetro Get-ADObject SearchBase para especificar el nombre distintivo como se indica a continuación.
Get-ADObject -Filter * -SearchBase 'OU=SALES,DC=SHELLPRO,DC=LOCAL'Este comando obtiene todos los objetos publicitarios del directorio activo mediante el parámetro SearchBase.
El resultado del comando anterior se proporciona a continuación.
Contacto Get-ADObject: buscar contacto de Active Directory
Si desea obtener contactos del directorio activo, ejecute el siguiente comando
Get-ADObject -Filter 'objectClass -eq "contact"' -Properties CN | Format-List CNEste comando busca contactos del directorio activo. Utiliza el parámetro Get-ADObject Filter para consultar la clase de objeto igual al contacto y obtener el nombre del contacto.
Exportar Get-ADObject a CSV
Si desea obtener un objeto del contenedor y exportarlo a un archivo CSV, use el siguiente comando
Get-ADObject -Filter 'objectClass -eq "container"' | Export-Csv -Path C:\PowerShell\adobject-container.csvEn el script de PowerShell anterior, el cmdlet Get-ADObject obtiene un objeto del contenedor.
Get-ADObject usa un parámetro de filtro para especificar la cadena de consulta como objectClass igual al contenedor y pasa el resultado al cmdlet Export-CSV.
El cmdlet Export-CSV exporta un objeto a un archivo CSV en la ruta especificada.
Get-ADObject SID: busque el nombre de usuario AD
Si desea obtener un nombre de usuario, nombre distinguido, nombre de cuenta samac, nombre principal de usuario por SID, ejecute el siguiente comando
$sid = 'S-1-5-21-1326752099-4012446882-462961959-1103'
Get-ADObject -Filter "objectSid -eq '$sid'" -Properties * | Select-Object name,distinguishedname,samaccountname,userprincipalnameEn el ejemplo anterior de Get-ADObject,
El SID de la cuenta de usuario se almacena en la variable $sid.
El cmdlet Get-ADObject utiliza un parámetro Filter para consultar objectSid igual a $sid y obtiene nombre de usuario, nombre distinguido, nombre de cuenta samac y nombre principal de usuario para un objeto.
Conclusión
Espero que el artículo anterior para encontrar objetos del directorio activo utilizando el cmdlet Get-ADObject le resulte útil.
Get-AdObject obtiene objetos del directorio activo, obtiene objetos publicitarios en una unidad organizativa específica, obtiene adobject por SID y exporta la lista de adobjects a un archivo CSV.
Puede utilizar el cmdlet Get-AdObject para obtener objetos del directorio activo y pasarlos al cmdlet Set-ADObject para modificar la propiedad del objeto del directorio activo.
Puede encontrar más temas sobre los comandos de PowerShell Active Directory y los conceptos básicos de PowerShell en la página de inicio de ShellGeek.
